# readme_gen/generator.py

def generate_readme(project_name, description, installation_instructions, usage_instructions, license_info):
    content = f"""
    # {project_name}

    ## Description
    {description}

    ## Installation
    ```
    {installation_instructions}
    ```

    ## Usage
    ```
    {usage_instructions}
    ```

    ## License
    {license_info}
    """
    
    with open("README.md", "w") as file:
        file.write(content.strip())
    print(f"README.md generated successfully for {project_name}!")



from setuptools import setup, find_packages

setup(
    name='readme_gen',
    version='0.1',
    packages=find_packages(),
    description='A simple package to generate README files for projects automatically.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',  # Indicates the format of long_description
    author='Eshan Iqbal',
    author_email='mireshan321@gmail.com',
    url='https://github.com/Eshaniqbal/Readme_gen-Package',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    install_requires=[
        # List your package dependencies here
    ],
)
